# PxlDB v1.1 (By PxlmastrXD)
import pickle


def version():
  print('PxlDB v1.1')


def create(dbname):
  with open(dbname, 'wb') as f:
    idb = {}
    pickle.dump(idb, f)
    print('Database created.')


class opendb:

  def __init__(self, database):
    with open(database, 'rb') as f:
      opendatabase = pickle.load(f)
    self.database = opendatabase
    self.openedfile = database

  def set(self, key, value):
    self.database[key] = value
    with open(self.openedfile) as f:
      pickle.dump(self.database, f)

  def get(self, key):
    return (self.database[key])



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['pixeldb']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'pixeldb',
    'version': '1.1.2',
    'description': 'A simple database written in Python.',
    'long_description': None,
    'author': 'PxlmastrXD',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3,<4',
}


setup(**setup_kwargs)
